@@ -19,7 +19,7 @@
  */
 
 /*
- * $Id: gbpserial.c,v 1.39 2008-10-15 16:13:13 rousseau Exp $
+ * $Id: gbpserial.c,v 1.40 2010-06-16 13:08:22 rousseau Exp $
  */
 
 #include <stdio.h>
@@ -339,7 +339,7 @@ RESPONSECODE OpenGBP(DWORD lun, LPSTR dev_name)
 
 	gbpDevice[reader].fd = open(dev_name, O_RDWR | O_NOCTTY);
 
-	if (gbpDevice[reader].fd <= 0)
+	if (gbpDevice[reader].fd < 0)
 	{
 		DEBUG_CRITICAL3("open %s: %s", dev_name, strerror(errno));
 		return STATUS_UNSUCCESSFUL;
