@@ -18,7 +18,7 @@
 */
 
 /*
- * $Id: resetGemPC410.c,v 1.10 2004-07-03 21:42:45 rousseau Exp $
+ * $Id: resetGemPC410.c,v 1.11 2009-04-12 09:25:08 rousseau Exp $
  */
 
 #include <errno.h>
@@ -45,6 +45,8 @@ int main(int argc, char *argv[])
 	int rv;
 	struct termios current_termios;
 
+	(void)argc;
+	(void)argv;
 
 	printf("Using device: " DEVICE "\n");
     if ((fd = open(DEVICE, O_RDWR | O_NOCTTY)) < 0)
