@@ -1,6 +1,6 @@
 /*
  *  GCCmds.c
- *  $Id: GCCmds.c,v 1.41 2009-04-12 08:48:23 rousseau Exp $
+ *  $Id: GCCmds.c,v 1.42 2010-01-03 15:48:40 rousseau Exp $
  *  ifd-GemPC
  *
  *  Created by Jean-Luc Giraud on Sat Oct 20 2001.
@@ -421,7 +421,7 @@ ifd_t GCCmdSetMode(const DWORD lun, const int mode)
 			break;
 
 		default:
-			DEBUG_CRITICAL2("Unkown mode: %02X", mode);
+			DEBUG_CRITICAL2("Unknown mode: %02X", mode);
 			break;
 	}
 
