@@ -1,5 +1,5 @@
 /*
- * $Id: GCdebug.h,v 1.11 2005-06-17 10:20:11 rousseau Exp $
+ * $Id: GCdebug.h,v 1.12 2009-02-17 19:57:10 rousseau Exp $
  * gcdebug.h: log (or not) messages using syslog
  * Copyright (C) 2001 Ludovic Rousseau <ludovic.rousseau@free.fr>
  * 
@@ -27,7 +27,11 @@
 #error "file Config.h NOT included"
 #endif
 
+#ifdef __APPLE__
+#include <debuglog.h>
+#else
 #include <PCSC/debuglog.h>
+#endif
 
 #ifndef _GCDEBUG_H_
 #define  _GCDEBUG_H_
