@@ -1,6 +1,6 @@
 /*
  *  GemCore.h
- *  $Id: GemCore.h,v 1.15 2004-07-03 21:42:48 rousseau Exp $
+ *  $Id: GemCore.h,v 1.16 2009-02-17 19:57:10 rousseau Exp $
  *  ifd-GemPC
  *
  *  Created by JL Giraud <jl.giraud@free.fr> on Sun Nov 19 2000.
@@ -14,6 +14,9 @@
 #define _GEMCORE_H_
 
 #include <pcsclite.h>
+#ifdef __APPLE__
+#include <wintypes.h>
+#endif
 
 /* Size of an ISO command (CLA+INS+P1+P2) */
 #define ISO_CMD_SIZE 4
