@@ -13,7 +13,7 @@
 /            See http://www.linuxnet.com for more information.
 / License:   See file COPYING.BSD
 /
-/ $Id: ifdhandler.c,v 1.27 2007-02-05 12:30:41 rousseau Exp $
+/ $Id: ifdhandler.c,v 1.29 2009-04-12 09:24:07 rousseau Exp $
 /
 ******************************************************************/
 
@@ -238,6 +238,8 @@ RESPONSECODE IFDHSetCapabilities(DWORD Lun, DWORD Tag,
 	/* By default, say it worked */
 
 	DEBUG_PERIODIC3("lun: %X, tag: %X", Lun, Tag);
+	(void)Length;
+	(void)Value;
 
 	if (iLunCheck(Lun))
 		return IFD_COMMUNICATION_ERROR;
@@ -265,6 +267,11 @@ RESPONSECODE IFDHSetProtocolParameters(DWORD Lun, DWORD Protocol,
 	 */
 
 	DEBUG_INFO2("lun: %X", Lun);
+	(void)Protocol;
+	(void)Flags;
+	(void)PTS1;
+	(void)PTS2;
+	(void)PTS3;
 
 	if (iLunCheck(Lun))
 		return IFD_COMMUNICATION_ERROR;
@@ -412,6 +419,7 @@ RESPONSECODE IFDHTransmitToICC(DWORD Lun, SCARD_IO_HEADER SendPci,
 	DWORD protocol;
 
 	DEBUG_INFO2("lun: %X", Lun);
+	(void)RecvPci;
 
 	if (iLunCheck(Lun))
 		return IFD_COMMUNICATION_ERROR;
@@ -547,6 +555,11 @@ RESPONSECODE IFDHControl(DWORD Lun, DWORD ControlCode, PUCHAR TxBuffer,
 	 */
 
 	DEBUG_INFO2("lun: %X", Lun);
+	(void)ControlCode;
+	(void)TxBuffer;
+	(void)TxLength;
+	(void)RxBuffer;
+	(void)RxLength;
 
 	/* this function is unsupported */
 	*pdwBytesReturned = 0;
